@@ -2,4 +2,4 @@ from .docker import DockerClient
 from .podman import PodmanClient
 
 
-__all__ = ['DockerClient', 'PodmanClient']
+__all__ = ["DockerClient", "PodmanClient"]
